@@ -1,27 +1,26 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include <config.h>
 #endif
 
 #include <stdio.h>
 #include <stdlib.h>
-#include <unistd.h>
 #include <string.h>
 #include <sys/types.h>
 #include <dirent.h>
 #include <sys/stat.h>
 #include <sys/time.h>
-#include <sys/param.h>
 #include <math.h>
 #include <fnmatch.h>
 #include <limits.h>
 #include <ctype.h>
 #include <time.h>
 #include <dirent.h>
-#include <dlfcn.h>      /* dlopen,dlclose,etc */
+
+#ifndef _MSC_VER
+# include <unistd.h>
+# include <sys/param.h>
+#endif
+
 #ifdef HAVE_EVIL
 # include <Evil.h>      /* for realpath */
 #else
@@ -30,6 +29,10 @@
 # include <glob.h>
 #endif /* ! HAVE_EVIL */
 
+#ifdef __MacOSX__
+# include <mach-o/dyld.h>
+#endif
+
 #include "embryo_cc_prefix.h"
 
 /* local subsystem functions */
@@ -37,6 +40,9 @@ static int _e_prefix_share_hunt(void);
 static int _e_prefix_fallbacks(void);
 static int _e_prefix_try_proc(void);
 static int _e_prefix_try_argv(char *argv0);
+#ifdef __MacOSX__
+static int _e_prefix_try_dyld(void);
+#endif
 
 /* local subsystem globals */
 static char *_exe_path = NULL;
@@ -90,8 +96,16 @@ e_prefix_determine(char *argv0)
      {
 	if (!_e_prefix_try_argv(argv0))
 	  {
-	     _e_prefix_fallbacks();
-	     return 0;
+#ifdef __MacOSX__
+		  if (!_e_prefix_try_dyld())
+		  {
+#endif
+			  _e_prefix_fallbacks();
+			  return 0;
+#ifdef __MacOSX__
+		  }
+#endif
+
 	  }
      }
    /* _exe_path is now a full absolute path TO this exe - figure out rest */
@@ -206,7 +220,7 @@ _e_prefix_share_hunt(void)
    char buf[4096], buf2[4096], *p;
    struct stat st;
 
-   /* sometimes this isnt the case - so we need to do a more exhaustive search
+   /* sometimes this isn't the case - so we need to do a more exhaustive search
     * through more parent and subdirs. hre is an example i have seen:
     *
     * /blah/whatever/exec/bin/exe
@@ -314,6 +328,21 @@ _e_prefix_fallbacks(void)
    return 1;
 }
 
+#ifdef __MacOSX__
+static int
+_e_prefix_try_dyld(void)
+{
+	char path[PATH_MAX];
+	uint32_t size = sizeof (path);
+
+	if (_NSGetExecutablePath(path, &size) != 0)
+		return 0;
+
+	_exe_path = strdup(path);
+	return 1;
+}
+#endif
+
 static int
 _e_prefix_try_proc(void)
 {
