@@ -9,7 +9,7 @@
  *  Copyright J.E. Hendrix, 1982, 1983
  *  Copyright T. Riemersma, 1997-2003
  *
- *  Version: $Id: embryo_cc_sc.h,v 1.14 2005/04/13 20:27:02 tsauerbeck Exp $
+ *  Version: $Id: embryo_cc_sc.h 56354 2011-01-29 03:19:51Z raster $
  *
  *  This software is provided "as-is", without any express or implied warranty.
  *  In no event will the authors be held liable for any damages arising from
@@ -27,13 +27,22 @@
  *      misrepresented as being the original software.
  *  3.  This notice may not be removed or altered from any source distribution.
  */
+
 #ifndef EMBRYO_CC_SC_H
 #define EMBRYO_CC_SC_H
+
 #include <limits.h>
 #include <stdarg.h>
 #include <stdio.h>
 #include <setjmp.h>
-#include "embryo_cc_osdefs.h"
+
+#ifndef _MSC_VER
+# include <stdint.h>
+#else
+# include <stddef.h>
+# include <Evil.h>
+#endif
+
 #include "embryo_cc_amx.h"
 
 /* Note: the "cell" and "ucell" types are defined in AMX.H */
@@ -51,7 +60,7 @@
 #define PREPROC_TERM  '\x7f'	/* termination character for preprocessor expressions (the "DEL" code) */
 #define sDEF_PREFIX   "default.inc"	/* default prefix filename */
 
-typedef void       *stkitem;	/* type of items stored on the stack */
+typedef intptr_t stkitem;	/* type of items stored on the stack */
 
 typedef struct __s_arginfo
 {				/* function argument info */
