@@ -1,7 +1,3 @@
-/*
- * vim:ts=8:sw=3:sts=8:noexpandtab:cino=>5n-3f0^-2{2
- */
-
 #ifdef HAVE_CONFIG_H
 # include "config.h"
 #endif
@@ -13,6 +9,10 @@
 #include <sys/time.h>
 #include <time.h>
 
+#ifdef _MSC_VER
+# include <winsock2.h>
+#endif
+
 #ifdef HAVE_EVIL
 # include <Evil.h>
 #endif
